@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-10-22 - v1.007
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.024.
+
+=item *
+
 2012-10-01 - v1.006
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.021.
@@ -219,6 +225,7 @@ ACB
 ACCA
 ACCARDO
 ACDALTON
+ACE
 ACESAVER
 ACESTER
 ACFEREN
@@ -319,6 +326,7 @@ AFRIKA
 AFRYER
 AGALLI
 AGARAN
+AGATORANO
 AGATT
 AGATTI
 AGENT
@@ -393,6 +401,7 @@ AKOLB
 AKR
 AKRON
 AKS
+AKSHAY
 AKSTE
 ALAMAZ
 ALANC
@@ -559,6 +568,7 @@ ANDREWN
 ANDREWO
 ANDREWS
 ANDREY
+ANDREYR
 ANDRI
 ANDY
 ANDYA
@@ -1154,6 +1164,7 @@ BLACKHAWK
 BLACKJ
 BLACKSTAR
 BLACKWIND
+BLACRA
 BLADE
 BLAIR
 BLAIZER
@@ -1622,6 +1633,7 @@ CHARDIN
 CHAROVARK
 CHARTGRP
 CHAS
+CHASONHTX
 CHATEAU
 CHCHCH
 CHE
@@ -1676,6 +1688,7 @@ CHRISCHU
 CHRISFR
 CHRISJ
 CHRISJCRA
+CHRISM
 CHRISN
 CHRISRD
 CHRISS
@@ -1809,6 +1822,7 @@ CODEBREAK
 CODECHILD
 CODEFISH
 CODEHELP
+CODEPOET
 CODEREPOS
 CODESCOUT
 CODYP
@@ -1931,6 +1945,7 @@ CSALAT
 CSANDEEP
 CSARVA
 CSCHAEFER
+CSCHORN
 CSCHWENZ
 CSCM
 CSEATON
@@ -2260,6 +2275,7 @@ DEP
 DEPESZ
 DEPP
 DEPPPP
+DERAHUL
 DEREK
 DEREKB
 DEREKP
@@ -2316,6 +2332,7 @@ DGOEHRIG
 DGOLD
 DGORLEY
 DGRAEVEJ
+DGRAHAM
 DGRANAU
 DGRAVES
 DGRECO
@@ -2723,6 +2740,7 @@ EASR
 EAST
 EASY
 EASYLIN
+EAU
 EAX
 EAYNG
 EBARLOW
@@ -2787,6 +2805,7 @@ EGGL
 EGILES
 EGOR
 EGORSH
+EGRANLUND
 EGROSS
 EGUPTA
 EGYPTUS
@@ -2834,6 +2853,7 @@ ELIJAH
 ELIKA
 ELISA
 ELISHEVA
+ELIXIR
 ELIZABETH
 ELLIOTF
 ELLIOTJS
@@ -3101,6 +3121,7 @@ FLUFFYNJ
 FLUOB
 FLUXOID
 FLW
+FLYGOAST
 FMACHABEE
 FMARIER
 FMC
@@ -3215,6 +3236,7 @@ FWNEPOMUK
 FWOJCIK
 FXFX
 FXN
+FXZUZ
 FYALCIN
 FYNTE
 GAAL
@@ -3254,6 +3276,7 @@ GARU
 GARY
 GARYAJ
 GARYK
+GASOLWU
 GATLIN
 GAUDEON
 GAURAV
@@ -3299,6 +3322,7 @@ GDR
 GDSL
 GEBELE
 GED
+GEDGE
 GEEKLADY
 GEEWIZ
 GEEZENSLA
@@ -3328,6 +3352,7 @@ GERRIT
 GERRYSTER
 GESTEP
 GETTY
+GFA
 GFIREBALL
 GFK
 GFLETCHER
@@ -3412,6 +3437,7 @@ GNOME
 GNURD
 GNUSTAVO
 GNUTOO
+GOCCY
 GODE
 GODSON
 GOEDICKE
@@ -3757,6 +3783,7 @@ HKOBA
 HKOCH
 HLARONS
 HLHAMILT
+HLIN
 HLP
 HLSANDER
 HLUBENOW
@@ -3821,6 +3848,7 @@ HPA
 HPALM
 HPETERS
 HPOUL
+HPSMITH
 HPWERNER
 HPYHACKER
 HRAFNKELL
@@ -4505,6 +4533,7 @@ JLAWRENC
 JLBEC
 JLBXKYFJO
 JLEADER
+JLEFLER
 JLENOIR
 JLENTON
 JLETUAL
@@ -4594,6 +4623,7 @@ JNQUINTIN
 JNSIMONN
 JNW
 JNWHITLEY
+JOACHIMDS
 JOAKIMBS
 JOANMG
 JOAO
@@ -5446,6 +5476,7 @@ LEIRA
 LEITE
 LEITGEBJ
 LEKUIN
+LELIR
 LEMBARK
 LEMON
 LEMP
@@ -5692,6 +5723,7 @@ MAFR
 MAG
 MAGGIEXYZ
 MAGH
+MAGICDRIV
 MAGICIAN
 MAGIKMAN
 MAGNACHEF
@@ -5820,6 +5852,7 @@ MARKPF
 MARKPRIOR
 MARKSMITH
 MARKSTOS
+MARKSYMAS
 MARKUSB
 MARKW
 MARKWHI
@@ -5948,6 +5981,7 @@ MBASTOS
 MBASUNOV
 MBATISTA
 MBB
+MBEAST
 MBEATO
 MBEEBE
 MBERENDS
@@ -7742,6 +7776,7 @@ REGODON
 REHSACK
 REICHERT
 REID
+REIFI
 REITER
 REITMAN
 REITMEIE
@@ -7833,6 +7868,7 @@ RIESM
 RIFFER
 RIGBYC
 RIIKI
+RIJ
 RIJA
 RIJK
 RIK
@@ -7973,6 +8009,7 @@ ROHLFSC
 ROKR
 ROLAND
 ROLFYONE
+ROLIVEIRA
 ROMAN
 ROMANF
 ROMDAV
@@ -8065,6 +8102,7 @@ RTHANGAM
 RTHOMPSON
 RTWARD
 RTXING
+RUBATTEL
 RUBINJ
 RUBLIND
 RUBYKAT
@@ -8216,6 +8254,7 @@ SATOH
 SATRAC
 SATZZ
 SAUBER
+SAULIUS
 SAUMITRA
 SAURABH
 SAV
@@ -8296,6 +8335,7 @@ SCR
 SCRAM
 SCRESTO
 SCRUBB
+SCS
 SCW
 SCYLDINGA
 SDAGUE
@@ -8510,6 +8550,7 @@ SIGURKO
 SIGZERO
 SILAS
 SILASMONK
+SILENCER
 SILI
 SILLYMOOS
 SILVAN
@@ -8928,6 +8969,7 @@ STWIGGER
 STYPNOW
 SUAVEANT
 SUBBU
+SUBHRADIP
 SUBSTACK
 SUDIP
 SUE
@@ -9082,6 +9124,7 @@ TATENO
 TATOUTE
 TATTOOJP
 TAULMARIL
+TAUNGER
 TAVIN
 TAWAN
 TAYERS
@@ -9189,6 +9232,7 @@ THECRAMPS
 THEDEVIL
 THEFISHY
 THEILING
+THEOK
 THEPLER
 THEREK
 THEREVMJ
@@ -9223,6 +9267,7 @@ TIAGOSOUS
 TIAO
 TIBBS
 TIBI
+TIEDEMANN
 TIGERPERL
 TIGRIS
 TILFORDC
@@ -9389,6 +9434,7 @@ TRACKONE
 TRANSWEBT
 TRAVAIL
 TRAVIS
+TRAVISB
 TRBC
 TRCJR
 TREEKI
@@ -9617,6 +9663,7 @@ VGIRISH
 VGOD
 VHOLER
 VIALVES
+VICHOU
 VICKBOCH
 VICTOR
 VICTORF
@@ -9635,6 +9682,7 @@ VILA
 VILEDA
 VILJUN
 VINAYSKI
+VINCENT
 VINIAN
 VINSWORLD
 VIORELS
@@ -9817,6 +9865,7 @@ WILLERT
 WILLIAM
 WILLIAMSG
 WILLIS
+WILLIW
 WILLMOJG
 WILLP
 WILLRUBEL
@@ -9987,6 +10036,7 @@ YAAKOV
 YAIR
 YAITSKOV
 YAK
+YAKEX
 YAKUBORI
 YAKWOO
 YALE
@@ -10077,6 +10127,7 @@ YSIMONX
 YSTH
 YSUZUKI
 YSYROTA
+YTAKEUCH
 YTURTLE
 YUDUBAN
 YUKI
@@ -10085,6 +10136,7 @@ YUKIO
 YULESHOW
 YUMATSUMO
 YUMPY
+YUNCHING
 YUNFANG
 YUPUG
 YURAN
@@ -10092,6 +10144,7 @@ YURY
 YUSUKE
 YUSUKEBE
 YUTA
+YUUKI
 YUYAW
 YUZI
 YVDHOVE
