@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pm_groups;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -38,6 +38,12 @@ Philippe Bruhat (BooK)
 
 =item *
 
+2012-10-22 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.024.
+
+=item *
+
 2012-09-10 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.018.
@@ -197,6 +203,7 @@ Minneapolis_pm
 Montreal_pm
 Nashville_pm
 Omaha_pm
+OrangeCounty_pm
 Ottawa_pm
 Philadelphia_pm
 Phoenix_pm
@@ -297,6 +304,7 @@ WhiteMountain_pm
 NH_pm
 Kaohsiung_pm
 Kw_pm
+Dresden_pm
 PortlandMaine_pm
 Cologne_pm
 Hamburg_pm
@@ -386,3 +394,5 @@ Cluj_pm
 Niigata_pm
 Hardware_pm
 Baku_pm
+Shijiazhuang_pm
+WhitePlains_pm
